@@ -15,6 +15,7 @@ All models:
    dtransform_in
    dtransform_out
    jupynb
+   pipeline_run
    usage
    version_yvzi
 
@@ -29,7 +30,7 @@ Helpers:
 """
 # This is lndb-schema-module yvzi.
 _schema_module_id = "yvzi"
-__version__ = "0.3.0"  # denote a pre-release for 0.1.0 with 0.1a1
+__version__ = "0.3.1"  # denote a pre-release for 0.1.0 with 0.1a1
 
 from . import id
 from ._core import (  # noqa
@@ -38,6 +39,7 @@ from ._core import (  # noqa
     dtransform_in,
     dtransform_out,
     jupynb,
+    pipeline_run,
     usage,
     usage_type,
     user,
